pub struct Capability(pub OctetString);Expand description
X.509 extension for CPoP capability (OID 1.3.6.1.4.1.54066.1.1).
Tuple Fields
0: OctetStringTrait Implementations
Sourceimpl AsExtension for Capability
impl AsExtension for Capability
Sourcefn critical(&self, _: &RdnSequence, _: &[Extension]) -> bool
fn critical(&self, _: &RdnSequence, _: &[Extension]) -> bool
Should the extension be marked critical
Sourcefn to_extension(
&self,
subject: &RdnSequence,
extensions: &[Extension],
) -> Result<Extension, Error>
fn to_extension( &self, subject: &RdnSequence, extensions: &[Extension], ) -> Result<Extension, Error>
Returns the Extension with the content encoded.
Sourceimpl AssociatedOid for Capability
impl AssociatedOid for Capability
Sourceconst OID: ObjectIdentifier
const OID: ObjectIdentifier
The OID associated with this type.
Sourceimpl Clone for Capability
impl Clone for Capability
Sourcefn clone(&self) -> Capability
fn clone(&self) -> Capability
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Capability
impl Debug for Capability
Sourceimpl Encode for Capability
impl Encode for Capability
Sourcefn encoded_len(&self) -> Result<Length>
fn encoded_len(&self) -> Result<Length>
Compute the length of this value in bytes when encoded as ASN.1 DER.
Sourcefn encode(&self, encoder: &mut impl Writer) -> Result<()>
fn encode(&self, encoder: &mut impl Writer) -> Result<()>
Encode this value as ASN.1 DER using the provided
Writer.Sourcefn encode_to_slice<'a>(&self, buf: &'a mut [u8]) -> Result<&'a [u8], Error>
fn encode_to_slice<'a>(&self, buf: &'a mut [u8]) -> Result<&'a [u8], Error>
Encode this value to the provided byte slice, returning a sub-slice
containing the encoded message.
Sourceimpl PartialEq for Capability
impl PartialEq for Capability
impl Eq for Capability
impl StructuralPartialEq for Capability